@@ -108,10 +108,10 @@ When CARE-FIRST-ONE is no-nil, ((a b c) (d e)) => (a d)."
         (apply #'cl-mapcar
                #'list lists))))))
 
-(if (fboundp 'flatten-tree)
-    (defalias 'pyim-flatten-tree 'flatten-tree)
-  (defun pyim-flatten-tree (tree)
-    "Take TREE and \"flatten\" it."
+(defun pyim-flatten-tree (tree)
+  "Take TREE and \"flatten\" it."
+  (if (fboundp 'flatten-tree)
+      (flatten-tree tree)
     (let (elems)
       (while (consp tree)
         (let ((elem (pop tree)))
@@ -131,6 +131,16 @@ When CARE-FIRST-ONE is no-nil, ((a b c) (d e)) => (a d)."
         (push (string-join list (or sep "")) output)))
     (nreverse output)))
 
+(defun pyim-split-list (list separator)
+  "Split LIST into sublists bounded by equal SEPARATOR."
+  (let (group result)
+    (dolist (x (append list (list separator)))
+      (if (not (equal x separator))
+          (push x group)
+        (push (nreverse group) result)
+        (setq group nil)))
+    (reverse result)))
+
 (defun pyim-char-before-to-string (num)
   "得到光标前第 NUM 个字符，并将其转换为字符串。"
   (let* ((point (point))
@@ -195,18 +205,10 @@ When CARE-FIRST-ONE is no-nil, ((a b c) (d e)) => (a d)."
     (setq unread-command-events nil))
   (setq unread-command-events
         (if (characterp key)
-            ;; Emacs >= 27 support (no-record . EVENT), please read emacs
-            ;; commit: f13d97b4de02586cce49909aa2f3f51fcb5daa5f (Fix defining
-            ;; keyboard macros in CUA mode)
-            (cons (if (> emacs-major-version 26)
-                      (cons 'no-record key)
-                    key)
-                  unread-command-events)
+            (cons (cons 'no-record key) unread-command-events)
           (append (cl-mapcan
                    (lambda (e)
-                     (list (if (> emacs-major-version 26)
-                               (cons 'no-record e)
-                             e)))
+                     (list (cons 'no-record e)))
                    (append key nil))
                   unread-command-events))))
 
