@@ -28,11 +28,7 @@
 ;;; Code:
 ;; * 代码                                                           :code:
 (require 'cl-lib)
-;; Emacs 26.1 之前的版本无法安装 posframe.
 (require 'posframe nil t)
-;; popup 不是 gnu elpa 包，所以不应该在这里加载它，加载它是由于向后兼容的原因，
-;; 未来可能删除。
-(require 'popup nil t)
 (require 'pyim-common)
 (require 'pyim-process)
 
@@ -110,7 +106,7 @@ page style."
   "Face used for the pyim page.")
 
 (defface pyim-page-border
-  '((t (:inherit pyim-page)))
+  '((t (:inherit pyim-page :background "gray")))
   "Face used for the pyim page border.
 Only useful when use posframe.")
 
