@@ -7,9 +7,9 @@
 ;;         Feng Shu <tumashu@163.com>
 ;; Maintainer: Feng Shu <tumashu@163.com>
 ;; URL: https://github.com/tumashu/pyim
-;; Version: 5.2.3
+;; Version: 5.3.0
 ;; Keywords: convenience, Chinese, pinyin, input-method
-;; Package-Requires: ((emacs "25.1") (async "1.6") (xr "1.13"))
+;; Package-Requires: ((emacs "27.1") (async "1.6") (xr "1.13"))
 
 ;; This file is part of GNU Emacs.
 
@@ -38,10 +38,6 @@
 (require 'pyim-common)
 (require 'pyim-cstring)
 (require 'pyim-dhashcache)
-;; NOTE: pyim 默认使用 dhashcache, 按理说不需要加载 dregcache, 但以前 pyim 支持
-;; 动态加载后端，由于简化代码的原因，这个功能取消了，require dregcache 是为了向
-;; 后兼容，未来也许会取消加载。
-(require 'pyim-dregcache)
 (require 'pyim-indicator)
 (require 'pyim-page)
 (require 'pyim-preview)
@@ -285,14 +281,13 @@ REFRESH-COMMON-DCACHE 已经废弃，不要再使用了。"
   "Add the selected text as a Chinese word into the personal dictionary."
   (interactive)
   (when (region-active-p)
-    (let ((string (buffer-substring-no-properties (region-beginning) (region-end)))
-          output)
+    (let ((string (buffer-substring-no-properties (region-beginning) (region-end))))
       (if (> (length string) 6)
-          (error "词条太长")
+          (error "PYIM: 所选词条太长。")
         (if (not (string-match-p "^\\cc+\\'" string))
-            (error "不是纯中文字符串")
-          (setq output (pyim-process-create-word string))
-          (message "将词条: %S 插入 personal file。" output)))
+            (error "PYIM: 所选词条包含非中文字符。")
+          (pyim-process-create-word string)
+          (message "PYIM: 将词条 %S 加入词库。" string)))
       (deactivate-mark)
       ;; NOTE: 这里必须返回 t, 因为这个函数的返回结果会被用来做为判断条件。
       t)))
@@ -331,18 +326,16 @@ MERGE-METHOD 是一个函数，这个函数需要两个数字参数，代表词
                (word (car content))
                (count (string-to-number
                        (or (car (cdr content)) "0")))
-               (criteria (car (cdr (cdr content))))
-               output)
-          (setq output
-                (pyim-process-create-word
-                 word nil
-                 (lambda (x)
-                   (funcall (or merge-method #'max)
-                            (or x 0)
-                            count))
-                 criteria))
+               (criteria (car (cdr (cdr content)))))
+          (pyim-process-create-word
+           word nil
+           (lambda (x)
+             (funcall (or merge-method #'max)
+                      (or x 0)
+                      count))
+           criteria)
           (unless silent
-            (message "* 导入 %S" output)))
+            (message "* 导入 %S" word)))
         (forward-line 1)))
     ;; 保存一下用户选择过的词生成的缓存和词频缓存，
     ;; 因为使用 async 机制更新 dcache 时，需要从 dcache 文件
@@ -396,7 +389,7 @@ FILE 的格式与 `pyim-dcache-export' 生成的文件格式相同，
         (when (and word (not (pyim-string-match-p "\\CC" word)))
           (pyim-process-delete-word word)))
       (forward-line 1)))
-  (message "pyim: 批量删词完成！"))
+  (message "PYIM: 批量删词完成！"))
 
 (defun pyim-delete-last-word ()
   "从个人词库中删除最新创建的词条。"
@@ -404,7 +397,7 @@ FILE 的格式与 `pyim-dcache-export' 生成的文件格式相同，
   (let ((word (pyim-process-last-created-word)))
     (when word
       (pyim-process-delete-word word)
-      (message "pyim: 从个人词库中删除词条 “%s” !" word))))
+      (message "PYIM: 将词条 %S 从个人词库中删除！" word))))
 
 (defalias 'pyim-delete-word-at-point
   #'pyim-process-delete-word-at-point)
@@ -419,14 +412,14 @@ FILE 的格式与 `pyim-dcache-export' 生成的文件格式相同，
       (when (and (< (length string) 6)
                  (> (length string) 0))
         (pyim-process-delete-word string)
-        (message "将词条: %S 从 personal 缓冲中删除。" string)
+        (message "将词条 %S 从个人词库中删除。" string)
         (deactivate-mark))))
    (t (let ((words (completing-read-multiple
                     "请选择需要删除的词条(可多选): "
                     (pyim-process-last-created-words))))
         (dolist (word words)
           (pyim-process-delete-word word)
-          (message "将词条: %S 从 personal 缓冲中删除。" word))))))
+          (message "将词条 %S 从个人词库中删除。" word))))))
 
 ;; ** 选词功能
 (defun pyim-select-word-simple ()
@@ -583,7 +576,7 @@ FILE 的格式与 `pyim-dcache-export' 生成的文件格式相同，
   (or (pyim-create-word-from-selection)
       (pyim-process-trigger-feature-run-p)
       (pyim-process-feed-entered-at-point-into-pyim)
-      (message "PYIM: `pyim-convert-string-at-point' did nothing.")))
+      (message "PYIM: 命令 `pyim-convert-string-at-point' 没有起作用！")))
 
 (defun pyim--activate-pyim ()
   "如果当前输入法设置为 pyim, 就激活它。"
